@@ -84,7 +84,7 @@ def unpack_absolute_path(paths_tuple):
     return absolute_paths
 
 
-def validate_imports(files, bad_imports_set, risky_imports_set):
+def validate_imports(js_files, html_files, bad_imports_set, risky_imports_set):
     """This function returns paths of files which have require/define statements present in the bad_imports_set imports set
 
     @param:
@@ -97,12 +97,13 @@ def validate_imports(files, bad_imports_set, risky_imports_set):
     improper_files <List>: A list of objects corresponding to files with bad imports
         Example: [
             { '/file_one.js': [ { 'bad': ['bad_one'], 'risky': ['risky_one', 'risky_two'] }] },
-            { '/file_two.js': [ { 'bad': ['bad_two', 'bad_three'], 'risky': ['risky_three'] }] }
+            { '/file_two.js': [ { 'bad': ['bad_two', 'bad_three'], 'risky': ['risky_three'] }] },
+            { '/file_three.html': [ { 'bad_html': ['bad_four', 'bad_five'], 'bad_risky': ['risky_four'] }] }
         ]
     """
     improper_files = []
     try:
-        for filepath in files:
+        for filepath in js_files:
             with open(filepath, "r", encoding="utf-8") as my_file:
                 matches = get_imported_matches(my_file.read())
                 bad_imports_in_file = []
@@ -124,6 +125,28 @@ def validate_imports(files, bad_imports_set, risky_imports_set):
                     identified_files = {"risky": risky_imports_in_file}
                 if identified_files:
                     improper_files.append({filepath: identified_files})
+        for filepath in html_files:
+            with open(filepath, "r", encoding="utf-8") as my_file:
+                matches = get_static_matches(my_file.read())
+                bad_imports_in_file = []
+                risky_imports_in_file = []
+                for match in matches:
+                    if match in bad_imports_set:
+                        bad_imports_in_file.append(match)
+                    elif match in risky_imports_set:
+                        risky_imports_in_file.append(match)
+                identified_files = None
+                if bad_imports_in_file and risky_imports_in_file:
+                    identified_files = {
+                        "bad_html": bad_imports_in_file,
+                        "risky_html": risky_imports_in_file,
+                    }
+                elif bad_imports_in_file:
+                    identified_files = {"bad_html": bad_imports_in_file}
+                elif risky_imports_in_file:
+                    identified_files = {"risky_html": risky_imports_in_file}
+                if identified_files:
+                    improper_files.append({filepath: identified_files})
     except Exception as exception:
         print(f"Exception while validating imports {exception}")
 
@@ -138,7 +161,8 @@ def communicate_bad_import_message(reporter, file_list):
     file_list <List>: A list of objects corresponding to files with bad imports
         Example: [
             { '/file_one.js': [ { 'bad': ['bad_one'], 'risky': ['risky_one', 'risky_two'] }] },
-            { '/file_two.js': [ { 'bad': ['bad_two', 'bad_three'], 'risky': ['risky_three'] }] }
+            { '/file_two.js': [ { 'bad': ['bad_two', 'bad_three'], 'risky': ['risky_three'] }] },
+            { '/file_three.html': [ { 'bad_html': ['bad_four', 'bad_five'], 'bad_risky': ['risky_four'] }] }
         ]
 
     returns
@@ -165,6 +189,23 @@ def communicate_bad_import_message(reporter, file_list):
                 f"Risky imports: {risky_imports_list}"
             )
             reporter.warn(message, source_file)
+        if "bad_html" in identified_files:
+            bad_html_imports_list = identified_files["bad_html"]
+            message = (
+                "Embed all your app's front-end JS dependencies in the /appserver directory. "
+                "If you import files from Splunk Web, your app might fail when Splunk Web updates "
+                f"in the future. Bad imports (HTML): {bad_html_imports_list}"
+            )
+            reporter.warn(message, source_file)
+        if "risky_html" in identified_files:
+            risky_html_imports_list = identified_files["risky_html"]
+            message = (
+                "Embed all your app's front-end JS dependencies in the /appserver directory. "
+                "If you import files from Splunk Web, your app might be at risk of failing "
+                "due to the removal of files when Splunk Web updates in the future. "
+                f"Risky imports (HTML): {risky_html_imports_list}"
+            )
+            reporter.warn(message, source_file)
 
 
 def get_imported_matches(file):
@@ -197,6 +238,59 @@ def get_imported_matches(file):
     return matches
 
 
+def parse_static_js_match(match):
+    """Utility function that parses a static/js file match into a require-style import.
+
+    @param
+    file <String>: Static file path
+
+    Returns
+    matches <String>: Require-style import path
+
+    Example:
+
+    '/static/js/foo/bar.js'
+
+    returns
+
+    'foo/bar'
+    """
+    split_match = match.split("/static/js/")
+    match = split_match[1] if len(split_match) > 1 else None
+    if match and "." in match:
+        return ".".join(match.split(".")[:-1])
+    return None
+
+
+def get_static_matches(file):
+    """Utility function that matches static imports in a given file.
+
+    @param
+    file <String>: File path
+
+    Returns
+    matches <Array>: List of imports done by static loading
+
+    Example:
+
+    make_url('/static/js/foo/bar.js')
+    make_url('/static/js/views/Base.js')
+
+    returns
+
+    ['foo/bar', 'views/Base']
+    """
+    matches = []
+    pattern = re.compile(r"(make_url)\([^)]+\)")
+    for matched_object in pattern.finditer(file):
+        imported_matches = re.finditer(r"['\"]([^'\"]*)['\"]", matched_object.group())
+        for imported in imported_matches:
+            match = parse_static_js_match(imported.group(1))
+            if match and match not in matches:
+                matches.append(match)
+    return matches
+
+
 def find_xml_nodes_usages_absolute_path(xml_files, nodes):
     """Unfortunately, need to duplicate this function as we need absolute paths
     Helper function to find xml node usage
