@@ -6,23 +6,20 @@ checks. One group consists of many checks. Implementation wise, each file in
 the folder of splunk_appinspect/checks/ is a group. Inside each on of those
 files are checks.
 """
-
-# Python Standard Libraries
 import imp
 import inspect
-from builtins import str as text
 import logging
 import operator
 import os
 import re
 import sys
+from builtins import str as text
 
-# Third-Party Libraries
 import bs4
 import markdown
+import semver
 import six
 
-# Custom Libraries
 import splunk_appinspect
 import splunk_appinspect.infra
 from splunk_appinspect.configuration_parser import InvalidSectionError
@@ -117,7 +114,7 @@ def generate_group(
         included_tags (List of Strings) - Tags to select checks with
         excluded_tags (List of Strings) - Tags to deselect checks with
         version (String) - The version of Splunk AppInspect being targeted
-        splunk_version (String) - The version of Splunk being targeted
+        splunk_version (semver.VersionInfo) - The version of Splunk being targeted
         custom_group (Boolean) - If the group being created is a custom group
     """
     if included_tags is None:
@@ -125,7 +122,7 @@ def generate_group(
     if excluded_tags is None:
         excluded_tags = []
     if version is None:
-        version = splunk_appinspect.version.__version__
+        version = semver.VersionInfo.parse(splunk_appinspect.version.__version__)
 
     # Group Generation
     logger.debug("Beginning check generation on group name: %s", group_module.__name__)
@@ -150,19 +147,19 @@ def generate_group(
     logger.debug("Is Custom Group: %s", custom_group)
     logger.debug("--- All Checks ---")
     for check in check_list:
-        logger_output = ("check_name:{},matches_tags:{},matches_version:{}").format(
-            check.name,
-            check.matches_tags(included_tags, excluded_tags),
-            check.matches_version(version),
+        logger_output = (
+            f"check_name:{check.name},"
+            f"matches_tags:{check.matches_tags(included_tags, excluded_tags)},"
+            f"matches_version:{check.matches_version(version)}"
         )
         logger.debug(logger_output)
 
     logger.debug("--- Filtered Checks ---")
     for check in filtered_checks:
-        logger_output = ("check_name:{},matches_tags:{},matches_version:{}").format(
-            check.name,
-            check.matches_tags(included_tags, excluded_tags),
-            check.matches_version(version),
+        logger_output = (
+            f"check_name:{check.name},"
+            f"matches_tags:{check.matches_tags(included_tags, excluded_tags)},"
+            f"matches_version:{check.matches_version(version)}"
         )
         logger.debug(logger_output)
 
@@ -197,7 +194,7 @@ def groups(
     if excluded_tags is None:
         excluded_tags = []
     if version is None:
-        version = splunk_appinspect.version.__version__
+        version = semver.VersionInfo.parse(splunk_appinspect.version.__version__)
 
     groups_to_return = []
     check_group_modules = import_group_modules(check_dirs)
@@ -317,7 +314,7 @@ class Group(object):
         bs_html = bs4.BeautifulSoup(html, "html.parser", store_line_numbers=False)
         if bs_html.h3 is not None and bs_html.h3.contents:
             return text(bs_html.h3.contents[0]).strip()
-        return u""
+        return ""
 
     def doc_html(self):
         """Returns the docstring (provided in markdown) as a html element."""
@@ -567,12 +564,10 @@ class Group(object):
                 included_tags, excluded_tags
             ) and check.matches_version(version)
             logger_output = (
-                "check_name:{},matches_tags:{},matches_version:{},should_check_be_returned:{}"
-            ).format(
-                check.name,
-                check.matches_tags(included_tags, excluded_tags),
-                check.matches_version(version),
-                should_check_be_returned,
+                f"check_name:{check.name},"
+                f"matches_tags:{check.matches_tags(included_tags, excluded_tags)},"
+                f"matches_version:{check.matches_version(version)},"
+                f"should_check_be_returned:{should_check_be_returned}"
             )
             logger.debug(logger_output)
 
@@ -721,7 +716,7 @@ class Check(object):
         # TODO: tests needed
         doc_text = self.doc_text()
         if include_version:
-            doc_text = "{} {}".format(doc_text, self.version_doc())
+            doc_text = f"{doc_text} {self.version_doc()}"
 
         return doc_text
 
@@ -733,7 +728,7 @@ class Check(object):
         )
 
         if include_version:
-            html = "{} {}".format(html, self.version_doc())
+            html = f"{html} {self.version_doc()}"
 
         return html
 
@@ -760,7 +755,7 @@ class Check(object):
     def version_doc(self):
         """Returns the version range of the check."""
         # TODO: tests needed
-        ver_doc = "({}-{})".format(self.min_version_doc, self.max_version_doc)
+        ver_doc = f"({self.min_version_doc}-{self.max_version_doc})"
         return ver_doc
 
     @property
@@ -921,9 +916,9 @@ class Check(object):
                     rm_ctx = resource_manager_context[arg]
                     if hasattr(rm_ctx, "state") and rm_ctx.state != 0:
                         error_string = (
-                            "{} has been skipped because the specified"
-                            " resource {} provided could not be setup correctly."
-                        ).format(self.fun.__name__, rm_ctx.__class__.__name__)
+                            f"{self.fun.__name__} has been skipped because the specified"
+                            f" resource {rm_ctx.__class__.__name__} provided could not be setup correctly."
+                        )
 
                         logger.debug(
                             "Resource %s has an invalid state %s",
@@ -945,12 +940,12 @@ class Check(object):
                 else:
                     # TODO: tests needed
                     error_string = (
-                        "{} has been skipped because the specified"
+                        f"{self.fun.__name__} has been skipped because the specified"
                         " instances provided did not match the"
                         " required instance types."
-                        " Instances provided: {}."
+                        f" Instances provided: {resource_manager_context.keys()}."
                         ""
-                    ).format(self.fun.__name__, resource_manager_context.keys())
+                    )
                     raise ResourceUnavailableException(error_string)
             self.fun.__call__(*args)
         except NotImplementedError:
@@ -963,11 +958,11 @@ class Check(object):
             reporter.fail(str(e))
         except InvalidSectionError as e:
             reporter.fail(
-                "{} is malformed. Details: {}".format(e.file_name, str(e)),
+                f"{e.file_name} is malformed. Details: {str(e)}",
                 e.file_name,
                 e.line_no,
             )
-        except:
+        except Exception:
             e = sys.exc_info()
             logging.exception(e)
             reporter.exception(e)
