@@ -6,14 +6,13 @@
 Ensure that `bindDNpassword` is not specified. For more, see [authentication.conf](http://docs.splunk.com/Documentation/Splunk/latest/Admin/Authenticationconf).
 """
 
-# Python Standard Library
 import logging
 import os
 
-# Custom Libraries
+from six import iteritems
+
 import splunk_appinspect
 from splunk_appinspect.splunk import normalizeBoolean
-from six import iteritems
 
 logger = logging.getLogger(__name__)
 
@@ -45,10 +44,8 @@ def check_authentication_conf_does_not_have_binddnpassword_property(app, reporte
                         "authentication.conf contains the"
                         " property bindDNpassword. Plain text"
                         " credentials should not be included in an"
-                        " app. Please remove the bindDNpassword="
-                        " property. Stanza: [{}]. File: {}, Line: {}.".format(
-                            stanza_name, file_path, lineno
-                        )
+                        " app. Please remove the bindDNpassword= property."
+                        f" Stanza: [{stanza_name}]. File: {file_path}, Line: {lineno}."
                     )
                     reporter.fail(reporter_output, file_path, lineno)
     else:
@@ -60,8 +57,7 @@ def check_authentication_conf_does_not_have_binddnpassword_property(app, reporte
 @splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.6.0")
 def check_saml_auth_should_not_turn_off_signed_assertion(app, reporter):
-    """Check that saml-* stanzas in `authentication.conf` do not turn off signedAssertion property
-    """
+    """Check that saml-* stanzas in `authentication.conf` do not turn off signedAssertion property"""
     config_file_paths = app.get_config_file_paths("authentication.conf")
     if config_file_paths:
         for directory, _ in iteritems(config_file_paths):
@@ -95,9 +91,9 @@ def _report_failure_for_saml_stanza_with_signed_assertion_off(
         reporter_output = (
             "SAML signedAssertion property is turned off, which will introduce vulnerabilities. "
             "Please turn the signedAssertion property on. "
-            "Stanza: [{}] "
-            "File: {}, "
-            "Line: {}.".format(stanza_name, file_path, stanza_lineno)
+            f"Stanza: [{stanza_name}] "
+            f"File: {file_path}, "
+            f"Line: {stanza_lineno}."
         )
         reporter.fail(reporter_output, file_path, stanza_lineno)
 
@@ -144,8 +140,9 @@ def check_scripted_authentication_has_valid_python_version_property(
                         != "python3"
                     ):
 
-                        reporter_output = "Scripted authentication [{}] is defined, and python.version should be explicitly set to python3.".format(
-                            auth_settings_stanza_name
+                        reporter_output = (
+                            f"Scripted authentication [{auth_settings_stanza_name}] is defined, "
+                            "and python.version should be explicitly set to python3."
                         )
                         section = authentication_conf_file.get_section(
                             auth_settings_stanza_name
@@ -154,9 +151,7 @@ def check_scripted_authentication_has_valid_python_version_property(
                         # TODO: further verify the script's compatibility of python3 interpreter if applicable
                 else:
                     reporter.warn(
-                        " Script authentication configuration for [{}] is missing".format(
-                            auth_settings_stanza_name
-                        )
+                        f" Script authentication configuration for [{auth_settings_stanza_name}] is missing"
                     )
 
     else:
