@@ -16,11 +16,13 @@ import sys
 
 import bs4
 from six import iteritems
+import semver
 
 import splunk_appinspect
 from splunk_appinspect.app_util import find_readmes
 from splunk_appinspect.check_routine import blacklist_conf, find_spl_command_usage
 from splunk_appinspect.lookup import LookupHelper
+from splunk_appinspect.regex_matcher import RegexBundle, RegexMatcher
 from splunk_appinspect.splunk.splunk_default_source_type_list import (
     SPLUNK_DEFAULT_SOURCE_TYPE,
 )
@@ -2108,3 +2110,58 @@ def check_for_implementing_tscollect(app, reporter):
     findings = find_spl_command_usage(app, "tscollect")
     for filepath, lineno in findings:
         reporter.fail(reporter_output, filepath, lineno)
+
+
+@splunk_appinspect.tags("cloud", "private_app", "future")
+@splunk_appinspect.cert_version(min="2.11.1")
+def check_python_sdk_version(app, reporter):
+    """Check that Splunk SDK for Python is up-to-date."""
+    # Minimum Splunk SDK for Python version supported
+    min_ver = semver.VersionInfo.parse("1.6.15")
+    ver_rex = r"\"User-Agent\": \"splunk-sdk-python/([\d.]+.*)\""
+    splunklib_exists = False
+    py_files = list(app.iterate_files(types=[".py"]))
+    # Look for the setting of the User-Agent header in binding.py
+    rexs = [RegexBundle(ver_rex)]
+    matcher = RegexMatcher(rexs)
+    if py_files:
+        for directory, file, _ in py_files:
+            # At a minimum the Python SDK should have a binding.py with
+            # a User-Agent that will contain the version number
+            if file != "binding.py":
+                continue
+            file_path = os.path.join(directory, file)
+            full_file_path = app.get_filename(file_path)
+            match_result = matcher.match_file(
+                filepath=full_file_path
+            )
+            for lineno, result in match_result:
+                splunklib_exists = True
+                file_path = os.path.join(directory, file)
+                # Parse the found version into semver, correcting for
+                # bad versions like "0.1" without a patch version
+                try:
+                    ver = re.search(ver_rex, result).groups()[0]
+                    if len(ver.split(".")) == 2:
+                        ver += ".0" # correct for versions without a patch
+                    parsed_ver = semver.VersionInfo.parse(ver)
+                except Exception as err:
+                    reporter_output = (
+                        "Issue parsing version found in for the Splunk SDK for "
+                        f"Python ({ver}). File: {file_path}. Error: {err}."
+                    )
+                    reporter.warn(reporter_output, file_path)
+                    continue
+                if parsed_ver < min_ver:
+                    # Found splunklib version is less than the minimum
+                    reporter_output = (
+                        "Detected an outdated version of the Splunk SDK for "
+                        f"Python ({ver}). Please upgrade to version "
+                        f"{min_ver[0]}.{min_ver[1]}.{min_ver[2]} or later. "
+                        f"File: {file_path}."
+                    )
+                    reporter.warn(reporter_output, file_path)
+    # binding.py not found
+    if not splunklib_exists:
+        reporter_output = "Splunk SDK for Python not found."
+        reporter.not_applicable(reporter_output)
