@@ -102,7 +102,7 @@ def check_no_default_stanzas(app, reporter):
                             lineno = conf.get_section(section_name).lineno
                             reporter_output = (
                                 f"{section_name} stanza was found in {file_path}. "
-                                "Please remove any [default], [general], [global] stanzas or properties "
+                                "Please remove any [default], [general], [global], [stash] stanzas or properties "
                                 "outside of a stanza (treated as default/global) "
                                 "from conf files defined by Splunk."
                                 "These stanzas/properties are not permitted "
