@@ -5,20 +5,21 @@
 
 Ensure that the index configuration file located in the **/default** folder is well formed and valid. For more, see [indexes.conf](http://docs.splunk.com/Documentation/Splunk/latest/Admin/Indexesconf).
 """
-
-# Python Standard Library
 import logging
 import os
+import re
 
-# Third Party library
 import six
 
-# Custom Libraries
 import splunk_appinspect
 
 report_display_order = 2
 logger = logging.getLogger(__name__)
 
+RE_INDEX_NAME = re.compile(
+    r"\$SPLUNK_DB\/(?P<index_name>[$\w]+)\/(db|colddb|thaweddb)$"
+)
+
 
 @splunk_appinspect.cert_version(min="1.1.23")
 @splunk_appinspect.tags("splunk_appinspect")
@@ -32,8 +33,8 @@ def check_indexes_conf_does_not_exist(app, reporter):
             " Administrators to meet the data storage and"
             " retention needs of the installation. Consider"
             " using Tags or Source Types to identify data"
-            " instead index location. File: {}"
-        ).format(file_path)
+            f" instead index location. File: {file_path}"
+        )
         reporter.fail(reporter_output, file_path)
 
 
@@ -59,10 +60,10 @@ def check_validate_default_indexes_not_modified(app, reporter):
         for section in indexes_config.sections():
             if section.name in default_indexes:
                 reporter_output = (
-                    "The default Splunk index [{}] was modified which is not "
-                    "allowed in the Splunk Cloud. Please remove this stanza. "
-                    "File: {}, Line: {}."
-                ).format(section.name, file_path, section.lineno)
+                    f"The default Splunk index [{section.name}] was modified which is "
+                    "not allowed in the Splunk Cloud. Please remove this stanza. "
+                    f"File: {file_path}, Line: {section.lineno}."
+                )
                 reporter.fail(reporter_output, file_path, section.lineno)
     else:
         reporter_output = "No `default/indexes.conf`file exists."
@@ -96,9 +97,10 @@ def check_index_definition_has_required_options(app, reporter):
                 if not section.has_option(required_option):
                     lineno = section.lineno
                     reporter_output = (
-                        "The {} index definition does not have the required option: {}. "
-                        "File: {}, Line: {}."
-                    ).format(section.name, required_option, file_path, lineno)
+                        f"The {section.name} index definition does not "
+                        f"have the required option: {required_option}. "
+                        f"File: {file_path}, Line: {lineno}."
+                    )
                     reporter.fail(reporter_output, file_path, lineno)
     else:
         reporter_output = "No `default/indexes.conf` file exists."
@@ -135,43 +137,39 @@ def check_indexes_conf_properties(app, reporter):
                     legal_path = _get_legal_path(section.name, option_name)
                     actual_path = option_value
                     if legal_path != actual_path:
+                        m = RE_INDEX_NAME.match(actual_path)
+                        if m and m.group("index_name") == "$_index_name":
+                            continue
                         reporter_output = (
-                            "In stanza {}, property {} should be {}, but is {} here. "
-                            "File: {}, Line: {}."
-                        ).format(
-                            section.name,
-                            option_name,
-                            legal_path,
-                            actual_path,
-                            file_path,
-                            option_lineno,
+                            f"In stanza {section.name}, property {option_name} "
+                            f"should be {legal_path}, but is {actual_path} here. "
+                            f"File: {file_path}, Line: {option_lineno}."
                         )
                         reporter.fail(reporter_output, file_path, option_lineno)
                 # not in option_white_list
                 elif option_name not in property_optional_white_list:
+                    allowed_properties = ", ".join(
+                        property_white_list + property_optional_white_list
+                    )
                     reporter_output = (
-                        "Illegal property {} found in stanza {}. Only properties [{}]"
-                        " are allowed in default/indexes.conf. File: {}, Line: {}."
-                    ).format(
-                        option_name,
-                        section.name,
-                        ", ".join(property_white_list + property_optional_white_list),
-                        file_path,
-                        option_lineno,
+                        f"Illegal property {option_name} found in stanza {section.name}."
+                        f" Only properties [{allowed_properties}] are allowed in"
+                        f" default/indexes.conf. File: {file_path}, Line: {option_lineno}."
                     )
                     reporter.fail(reporter_output, file_path, option_lineno)
 
 
 def _get_legal_path(index_name, property_name):
     """
-        [<index_name>]
-        homePath   = $SPLUNK_DB/<index_name>/db
-        coldPath   = $SPLUNK_DB/<index_name>/colddb
-        thawedPath = $SPLUNK_DB/<index_name>/thaweddb
+    [<index_name>]
+    homePath   = $SPLUNK_DB/<index_name>/db
+    coldPath   = $SPLUNK_DB/<index_name>/colddb
+    thawedPath = $SPLUNK_DB/<index_name>/thaweddb
     """
-    pattern = "$SPLUNK_DB/{}/{}"
+
     pattern_dict = {"homePath": "db", "coldPath": "colddb", "thawedPath": "thaweddb"}
-    return pattern.format(index_name, pattern_dict[property_name])
+    pattern = f"$SPLUNK_DB/{index_name}/{pattern_dict[property_name]}"
+    return pattern
 
 
 @splunk_appinspect.tags("cloud", "python3_version", "private_app")
@@ -213,13 +211,12 @@ def check_coldToFrozenScript_has_valid_python_version_property(
                             try:
                                 with open(full_file_path, "rb") as f:
                                     ast.parse(f.read())
-                            except:
+                            except Exception:
+                                value = section.get_option("coldToFrozenScript").value
                                 reporter.fail(
-                                    "coldToFrozenScript option {} specifies a script that is not Python 3 compatible, "
-                                    "Please upgrade your Python script to be Python 3 "
-                                    "compatible.".format(
-                                        section.get_option("coldToFrozenScript").value
-                                    ),
+                                    f"coldToFrozenScript option {value} specifies "
+                                    "a script that is not Python 3 compatible, "
+                                    "Please upgrade your Python script to be Python 3 compatible.",
                                     file_path,
                                     section.lineno,
                                 )
