@@ -5,12 +5,10 @@
 
 Ensure that the **outputs.conf** file located in the **/default** folder of the app is well formed and valid. For more, see [outputs.conf](http://docs.splunk.com/Documentation/Splunk/latest/Admin/Outputsconf).
 """
-
-# Python Standard Library
 import os
+
 from six import iteritems
 
-# Custom Libraries
 import splunk_appinspect
 from splunk_appinspect.splunk import normalizeBoolean
 
@@ -18,8 +16,7 @@ from splunk_appinspect.splunk import normalizeBoolean
 @splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.4")
 def check_if_outputs_conf_exists(app, reporter):
-    """Check that forwarding enabled in 'outputs.conf' is failed in cloud
-    """
+    """Check that forwarding enabled in 'outputs.conf' is failed in cloud"""
     config_file_paths = app.get_config_file_paths("outputs.conf")
     option_name = "disabled"
 
@@ -38,11 +35,9 @@ def check_if_outputs_conf_exists(app, reporter):
                 for section in section_names:
                     if not outputs_conf.has_option(section, option_name):
                         reporter_output = (
-                            "From `{}/outputs.conf`, output is enabled"
-                            " by default."
-                            " This is prohibited in Splunk"
-                            " Cloud. File: {}"
-                        ).format(directory, file_path)
+                            f"From `{directory}/outputs.conf`, output is enabled by default."
+                            f" This is prohibited in Splunk Cloud. File: {file_path}"
+                        )
                         reporter.fail(reporter_output, file_path)
                     else:
                         is_disabled = normalizeBoolean(
@@ -57,8 +52,8 @@ def check_if_outputs_conf_exists(app, reporter):
                                 .lineno
                             )
                             reporter_output = (
-                                "From `{}/outputs.conf`, output is enabled with 'disabled = False'."
-                                " This is prohibited in Splunk"
-                                " Cloud. Stanza: [{}]. File: {}, Line: {}."
-                            ).format(directory, section, file_path, lineno)
+                                f"From `{directory}/outputs.conf`, output is enabled with 'disabled = False'."
+                                " This is prohibited in Splunk Cloud. "
+                                f" Stanza: [{section}]. File: {file_path}, Line: {lineno}."
+                            )
                             reporter.fail(reporter_output, file_path, lineno)
