@@ -9,20 +9,17 @@ formed and valid.
 - [props.conf](http://docs.splunk.com/Documentation/Splunk/latest/Admin/Propsconf)
 - [transforms.conf](http://docs.splunk.com/Documentation/Splunk/latest/Admin/Transformsconf)
 """
-
-# Python Standard Library
 import logging
-import re
 import os
+import re
 
-# Custom Libraries
-import splunk_appinspect
 from six import iteritems
 
+import splunk_appinspect
+from splunk_appinspect.configuration_file import ConfigurationFile, ConfigurationSection
 from splunk_appinspect.splunk_pretrained_sourcetypes_list import (
     SPLUNK_PRETRAINED_SOURCETYPES,
 )
-from splunk_appinspect.configuration_file import ConfigurationSection, ConfigurationFile
 
 report_display_order = 2
 logger = logging.getLogger(__name__)
@@ -53,8 +50,9 @@ def check_props_conf_has_transforms_option_and_transforms_conf_exist(app, report
                     else:
                         reporter_output = (
                             "No transforms.conf exists for "
-                            "[{}], {}. File: {}, Line: {}."
-                        ).format(section.name, setting.name, file_path, section.lineno)
+                            f"[{section.name}], {setting.name}. "
+                            f"File: {file_path}, Line: {section.lineno}."
+                        )
                         reporter.fail(reporter_output, file_path, section.lineno)
         else:
             reporter_output = "No TRANSFORMS- properties were declared."
@@ -95,25 +93,16 @@ def check_props_conf_has_transforms_option_and_transforms_conf_has_matching_stan
                                 pass  # Do nothing, test passed
                             else:
                                 reporter_output = (
-                                    "Transforms.conf does not"
-                                    " contain a [{}] stanza to match"
-                                    " props.conf [{}] {}={}."
-                                    " File: {}, Line: {}."
-                                ).format(
-                                    props_transforms_stanza_name.strip(),
-                                    props_section.name,
-                                    setting.name,
-                                    setting.value,
-                                    file_path,
-                                    props_section.lineno,
+                                    "Transforms.conf does not contain"
+                                    f" a [{props_transforms_stanza_name.strip()}] stanza to match"
+                                    f" props.conf [{props_section.name}] {setting.name}={setting.value}."
+                                    f" File: {file_path}, Line: {props_section.lineno}."
                                 )
                                 reporter.fail(
                                     reporter_output, file_path, props_section.lineno
                                 )
             else:
-                reporter_output = "No transforms.conf exists. File: {}".format(
-                    file_path
-                )
+                reporter_output = f"No transforms.conf exists. File: {file_path}"
                 reporter.fail(reporter_output, file_path)
         else:
             reporter_output = "No TRANSFORMS- properties were declared."
@@ -152,9 +141,8 @@ def check_props_conf_has_report_option_and_transforms_conf_exist(app, reporter):
                         else:
                             reporter_output = (
                                 "No transforms.conf exists for "
-                                "[{}], {}. File: {}, Line: {}."
-                            ).format(
-                                section.name, setting.name, file_path, section.lineno
+                                f"[{section.name}], {setting.name}. "
+                                f"File: {file_path}, Line: {section.lineno}."
                             )
                             reporter.fail(reporter_output, file_path, section.lineno)
             else:
@@ -203,25 +191,16 @@ def check_props_conf_has_report_option_and_transforms_conf_has_matching_stanza(
                                     pass  # Do nothing, test passed
                                 else:
                                     reporter_output = (
-                                        "Transforms.conf does not"
-                                        " contain a [{}] stanza to match"
-                                        " props.conf [{}] {}={}."
-                                        " File: {}, Line: {}."
-                                    ).format(
-                                        props_transforms_stanza_name.strip(),
-                                        props_section.name,
-                                        setting.name,
-                                        setting.value,
-                                        file_path,
-                                        props_section.lineno,
+                                        "Transforms.conf does not contain"
+                                        f" a [{props_transforms_stanza_name.strip()}] stanza to match"
+                                        f" props.conf [{props_section.name}] {setting.name}={setting.value}."
+                                        f" File: {file_path}, Line: {props_section.lineno}."
                                     )
                                     reporter.fail(
                                         reporter_output, file_path, props_section.lineno
                                     )
                 else:
-                    reporter_output = "No transforms.conf exists. File: {}".format(
-                        file_path
-                    )
+                    reporter_output = f"No transforms.conf exists. File: {file_path}"
                     reporter.fail(reporter_output, file_path)
             elif directory == "default":
                 reporter_output = "No REPORT- properties were declared."
@@ -267,10 +246,11 @@ def check_props_conf_has_report_option_and_transforms_conf_has_required_option(
                             "json",
                             "xml",
                         ]:
+                            KV_MODE_value = props_section.get_option("KV_MODE").value
                             reporter_output = (
                                 "REPORT- property stanza has KV_MODE"
-                                " = {} so DELIMS/REGEX not required."
-                            ).format(props_section.get_option("KV_MODE").value)
+                                f" = {KV_MODE_value} so DELIMS/REGEX not required."
+                            )
                             reporter.not_applicable(reporter_output)
                             continue
                         for setting in props_section.settings_with_key_pattern(
@@ -282,26 +262,28 @@ def check_props_conf_has_report_option_and_transforms_conf_has_required_option(
                                 if transforms_config.has_section(
                                     props_transforms_stanza_name.strip()
                                 ):
-                                    props_transforms_stanza: ConfigurationSection = transforms_config.get_section(
-                                        props_transforms_stanza_name.strip()
+                                    props_transforms_stanza: ConfigurationSection = (
+                                        transforms_config.get_section(
+                                            props_transforms_stanza_name.strip()
+                                        )
                                     )
                                     if props_transforms_stanza.has_setting_with_pattern(
                                         "regex"
                                     ):
-                                        regex_str: str = props_transforms_stanza.get_option(
-                                            "REGEX"
-                                        ).value
+                                        regex_str: str = (
+                                            props_transforms_stanza.get_option(
+                                                "REGEX"
+                                            ).value
+                                        )
                                         matches = re.search(
                                             r"(?<!\\)\(.*(?<!\\)\)", regex_str
                                         )
                                         if matches is None:
                                             reporter_output = (
-                                                "Transforms.conf [{}]"
+                                                f"Transforms.conf [{props_transforms_stanza_name.strip()}]"
                                                 " specify a REGEX without any capturing group."
                                                 " This is an incorrect usage."
                                                 " Please include at least one capturing group."
-                                            ).format(
-                                                props_transforms_stanza_name.strip(),
                                             )
                                             reporter.fail(
                                                 reporter_output,
@@ -320,16 +302,10 @@ def check_props_conf_has_report_option_and_transforms_conf_has_required_option(
                                         pass
                                     else:
                                         reporter_output = (
-                                            "Transforms.conf [{}] does not"
-                                            " specify DELIMS or REGEX"
-                                            " to match props.conf [{}], {}."
-                                            " File: {}, Line: {}."
-                                        ).format(
-                                            props_transforms_stanza_name.strip(),
-                                            props_section.name,
-                                            setting.name,
-                                            file_path,
-                                            props_section.lineno,
+                                            f"Transforms.conf [{props_transforms_stanza_name.strip()}]"
+                                            " does not specify DELIMS or REGEX to match"
+                                            f" props.conf [{props_section.name}], {setting.name}."
+                                            f" File: {file_path}, Line: {props_section.lineno}."
                                         )
                                         reporter.fail(
                                             reporter_output,
@@ -338,25 +314,16 @@ def check_props_conf_has_report_option_and_transforms_conf_has_required_option(
                                         )
                                 else:
                                     reporter_output = (
-                                        "Transforms.conf does not"
-                                        " contain a [{}] stanza to match"
-                                        " props.conf [{}] {}={}."
-                                        " File: {}, Line: {}."
-                                    ).format(
-                                        props_transforms_stanza_name.strip(),
-                                        props_section.name,
-                                        setting.name,
-                                        setting.value,
-                                        file_path,
-                                        props_section.lineno,
+                                        "Transforms.conf does not contain"
+                                        f" a [{props_transforms_stanza_name.strip()}] stanza to match"
+                                        f" props.conf [{props_section.name}] {setting.name}={setting.value}."
+                                        f" File: {file_path}, Line: {props_section.lineno}."
                                     )
                                     reporter.fail(
                                         reporter_output, file_path, props_section.lineno
                                     )
                 else:
-                    reporter_output = "No transforms.conf exists. File: {}".format(
-                        file_path
-                    )
+                    reporter_output = f"No transforms.conf exists. File: {file_path}"
                     reporter.fail(reporter_output, file_path)
             else:
                 reporter_output = "No REPORT- properties were declared."
@@ -370,12 +337,12 @@ def check_props_conf_has_report_option_and_transforms_conf_has_required_option(
 @splunk_appinspect.cert_version(min="1.1.16")
 def check_props_conf_regex_stanza_name_followed_by_double_colon(app, reporter):
     """Check that the props.conf stanzas (delayedrule, host, rule, or source)
-    are followed by `::`.
+        are followed by `::`.
 
-For example:
+    For example:
 
- * `[host::nyc*]`
- * `[rule::bar_some]`
+     * `[host::nyc*]`
+     * `[rule::bar_some]`
     """
     config_file_paths = app.get_config_file_paths("props.conf")
     if config_file_paths:
@@ -388,8 +355,7 @@ For example:
             regex_stanza_names = ["host", "delayedrule", "rule", "source"]
 
             regex_stanza_patterns = [
-                "^{}".format(regex_stanza_name)
-                for regex_stanza_name in regex_stanza_names
+                f"^{regex_stanza_name}" for regex_stanza_name in regex_stanza_names
             ]
             regex_stanza_patterns_str = "|".join(regex_stanza_patterns)
             regex_stanza_patterns_regex_object = re.compile(
@@ -397,7 +363,7 @@ For example:
             )
 
             valid_regex_stanza_patterns = [
-                r"^{}(?:::|\w+)".format(regex_stanza_pattern)
+                fr"^{regex_stanza_pattern}(?:::|\w+)"
                 for regex_stanza_pattern in regex_stanza_names
             ]
             valid_regex_stanza_patterns_str = "|".join(valid_regex_stanza_patterns)
@@ -420,8 +386,9 @@ For example:
                     reporter_output = (
                         "Missing colon(s) detected for a props.conf"
                         " regex stanza name. Make sure it uses `::`."
-                        " Stanza Name: {}. File: {}, Line: {}."
-                    ).format(invalid_props_stanza_name, file_path, lineno)
+                        f" Stanza Name: {invalid_props_stanza_name}."
+                        f" File: {file_path}, Line: {lineno}."
+                    )
                     reporter.fail(reporter_output, file_path, lineno)
     else:
         reporter_output = "No props.conf file exists."
@@ -467,8 +434,9 @@ def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
             if setting.name.startswith("TRANSFORMS-"):
                 if not app.file_exists(transforms_file_path):
                     reporter_output = (
-                        "No transforms.conf exists for setting in props.conf: {}={}"
-                    ).format(setting.name, setting.value)
+                        "No transforms.conf exists for setting in "
+                        f"props.conf: {setting.name}={setting.value}"
+                    )
                     reporter.warn(reporter_output, props_file_path, setting.lineno)
                     return
 
@@ -478,13 +446,8 @@ def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
 
                     if not transforms_conf.has_section(transform_stanza_name):
                         reporter_output = (
-                            "Transforms.conf does not contain a [{}] stanza"
-                            "to match props.conf [{}] {}={}"
-                        ).format(
-                            transform_stanza_name.strip(),
-                            section.name,
-                            setting.name,
-                            setting.value,
+                            f"Transforms.conf does not contain a [{transform_stanza_name.strip()}] stanza"
+                            f"to match props.conf [{section.name}] {setting.name}={setting.value}"
                         )
                         reporter.warn(reporter_output, props_file_path, setting.lineno)
                         return
@@ -497,9 +460,9 @@ def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
                         dest = transforms_section.get_option("DEST_KEY")
                         if dest.value not in allowed_dest_keys:
                             reporter_output = (
-                                "Modifying the {} field for a pretrained"
-                                "sourcetype is not allowed."
-                            ).format(dest.value)
+                                f"Modifying the {dest.value} field for "
+                                "a pretrained sourcetype is not allowed."
+                            )
                             reporter.warn(
                                 reporter_output, transforms_file_path, dest.lineno
                             )
@@ -536,11 +499,11 @@ def check_props_conf_extract_option_has_named_capturing_group(app, reporter):
                             pass
                         else:
                             reporter_output = (
-                                "[{}] setting in props.conf specified a regex"
+                                f"[{setting.name}] setting in props.conf specified a regex"
                                 " without any named capturing group."
                                 " This is an incorrect usage."
                                 " Please include at least one named capturing group."
-                            ).format(setting.name,)
+                            )
                             reporter.fail(reporter_output, file_path, setting.lineno)
             elif directory == "default":
                 reporter_output = "No EXTRACT- properties were declared."
