@@ -3,16 +3,17 @@
 """Each of these add metadata to the function they wrap. This metadata is then
 used by the Check object that encloses it.
 """
+import semver
 
 
-def cert_version(min="1.0", max=None):
+def cert_version(min="1.0.0", max=None):
     """
     Allows specifying which checks should be run at a given certification level. Both min and max define an _inclusive_ range, compared as strings
     """
 
     def wrap(check):
-        check.min_version = min
-        check.max_version = max
+        check.min_version = semver.VersionInfo.parse(min)
+        check.max_version = semver.VersionInfo.parse(max) if max else None
         return check
 
     return wrap
