@@ -1,14 +1,11 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 """Splunk app file resource abstraction module. Parsers provided for xml, lxml-xml and lxml format."""
 
-# Python Standard Libraries
-import os
 import logging
+import os
 
-# Third-Party Libraries
 import bs4
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -32,4 +29,4 @@ class FileResource(object):
             raise
         else:
             logging.error("%s file is not supported!", fmt)
-            raise Exception("{} file is not supported!".format(fmt))
+            raise Exception(f"{fmt} file is not supported!")
