@@ -1,11 +1,9 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 
-# Python Standard Libraries
 import logging
-import re
 import os
+import re
 
-# Custom Libraries
 from . import inspected_file
 
 logger = logging.getLogger(__name__)
@@ -22,7 +20,7 @@ class RegexMatcher(object):
         self.has_valid_files = False
 
     def match(self, string, regex_option=0):
-        """ return all match results in sorted order """
+        """return all match results in sorted order"""
         ans = []
         for regex_bundle in self.__regex_bundle_list:
             pattern = re.compile(regex_bundle.general_regex_string, regex_option)
@@ -33,7 +31,7 @@ class RegexMatcher(object):
         return ans
 
     def match_string_array(self, string_array, regex_option=0):
-        """ return all match results in (lineno, result) tuple and in sorted order """
+        """return all match results in (lineno, result) tuple and in sorted order"""
         ans = []
         for regex_bundle in self.__regex_bundle_list:
             pattern = re.compile(regex_bundle.general_regex_string, regex_option)
@@ -47,7 +45,7 @@ class RegexMatcher(object):
         return ans
 
     def match_file(self, filepath, regex_option=0, excluded_comments=True):
-        """ return all match results in (lineno, result) tuple and in sorted order """
+        """return all match results in (lineno, result) tuple and in sorted order"""
         if not os.path.exists(filepath):
             return []
 
@@ -263,7 +261,9 @@ class SecretDisclosureInAllFilesMatcher(RegexMatcher):
             RegexBundle(
                 r"(?i)github.{0,10}=\s*[\'\"][0-9a-f]{40}[\'\"]"
             ),  # GitHub personal access token
-            RegexBundle(r"(?i)\"client_secret\":\"[a-zA-Z0-9-_]{24}\""),  # Google Oauth
+            RegexBundle(
+                r"(?i)\"client_secret\":\s*\"[a-zA-Z0-9-_]{24}\""
+            ),  # Google Oauth
             RegexBundle(r"(?i)AKIA[0-9A-Z]{16}"),  # AWS API Key
             RegexBundle(
                 r"(?i)heroku.*[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}"
