@@ -1,19 +1,14 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 """Splunk AppInspect Validation Report module"""
-
-# Python Standard Libraries
 import collections
 import copy
-from datetime import datetime
 import logging
+from datetime import datetime
+
 from six import iteritems, itervalues
 
-# Third-Party Libraries
-# N/A
-# Custom Libraries
 import splunk_appinspect
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -108,6 +103,7 @@ class ApplicationValidationReport(object):
         self.app_description = application.description
         self.app_version = application.version
         self.app_name = application.label
+        self.package_id = application.package_id
         self.app_hash = application._get_hash()  # pylint: disable=W0212
 
         self._results = None
@@ -130,7 +126,7 @@ class ApplicationValidationReport(object):
         grouped_results = collections.defaultdict(list)
         # Get the results, adding basic ordering
         for group, check, reporter in self.results:
-            key = "{}-{}".format(group.report_display_order, group.name)
+            key = f"{group.report_display_order}-{group.name}"
             grouped_results[key].append((group, check, reporter))
 
         # Return the groups in order of key
